@@ -1,4 +1,4 @@
-from ems_config.config import parse_config
+from ems_config.config import parse_config, parse_remote_config
 from ems_config.helpers import *
 from ems_config.vars import *
 
