@@ -24,3 +24,11 @@ def parse_list_or_none(cfg_section, key, data_type=str, delimiter=','):
 
 def get_from_app_data(p):
     return os.path.join(APP_DATA_DIR, p)
+
+
+def get_from_cfg_or_env(cfg, cfg_key, key, default, prefix_cfg=True, env_key=None):
+    env_key = env_key if env_key is not None else f"{cfg_key}_{key}" if prefix_cfg else key
+    try:
+        return cfg[cfg_key].get(key, fallback=os.getenv(env_key, default))
+    except KeyError:
+        return os.getenv(env_key, default)
